# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: odsbox/proto/ods.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16odsbox/proto/ods.proto\x12\x03ods\"\x1d\n\x0bStringArray\x12\x0e\n\x06values\x18\x01 \x03(\t\"\x1f\n\tLongArray\x12\x12\n\x06values\x18\x01 \x03(\x05\x42\x02\x10\x01\" \n\nFloatArray\x12\x12\n\x06values\x18\x01 \x03(\x02\x42\x02\x10\x01\"\"\n\x0c\x42ooleanArray\x12\x12\n\x06values\x18\x01 \x03(\x08\x42\x02\x10\x01\"\x1b\n\tByteArray\x12\x0e\n\x06values\x18\x01 \x01(\x0c\"!\n\x0b\x44oubleArray\x12\x12\n\x06values\x18\x01 \x03(\x01\x42\x02\x10\x01\"#\n\rLonglongArray\x12\x12\n\x06values\x18\x01 \x03(\x03\x42\x02\x10\x01\"\x1e\n\x0c\x42ytestrArray\x12\x0e\n\x06values\x18\x01 \x03(\x0c\"\xd8\x11\n\nDataMatrix\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\'\n\x07\x63olumns\x18\x04 \x03(\x0b\x32\x16.ods.DataMatrix.Column\x12\x11\n\trow_start\x18\x05 \x01(\x03\x12\x14\n\x0cvalues_start\x18\x06 \x01(\x03\x12:\n\x12values_update_mode\x18\x07 \x01(\x0e\x32\x1e.ods.DataMatrix.UpdateModeEnum\x12\x1c\n\x14values_remove_length\x18\x08 \x01(\x03\x1a\xa1\x0f\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\x12\x0f\n\x07unit_id\x18\x03 \x01(\x03\x12%\n\taggregate\x18\x04 \x01(\x0e\x32\x12.ods.AggregateEnum\x12$\n\tdata_type\x18\x05 \x01(\x0e\x32\x11.ods.DataTypeEnum\x12\x13\n\x07is_null\x18\x06 \x03(\x08\x42\x02\x10\x01\x12(\n\x0cstring_array\x18\x07 \x01(\x0b\x32\x10.ods.StringArrayH\x00\x12$\n\nlong_array\x18\x08 \x01(\x0b\x32\x0e.ods.LongArrayH\x00\x12&\n\x0b\x66loat_array\x18\t \x01(\x0b\x32\x0f.ods.FloatArrayH\x00\x12*\n\rboolean_array\x18\n \x01(\x0b\x32\x11.ods.BooleanArrayH\x00\x12$\n\nbyte_array\x18\x0b \x01(\x0b\x32\x0e.ods.ByteArrayH\x00\x12(\n\x0c\x64ouble_array\x18\x0c \x01(\x0b\x32\x10.ods.DoubleArrayH\x00\x12,\n\x0elonglong_array\x18\r \x01(\x0b\x32\x12.ods.LonglongArrayH\x00\x12*\n\rbytestr_array\x18\x0e \x01(\x0b\x32\x11.ods.BytestrArrayH\x00\x12<\n\rstring_arrays\x18\x0f \x01(\x0b\x32#.ods.DataMatrix.Column.StringArraysH\x00\x12\x38\n\x0blong_arrays\x18\x10 \x01(\x0b\x32!.ods.DataMatrix.Column.LongArraysH\x00\x12:\n\x0c\x66loat_arrays\x18\x11 \x01(\x0b\x32\".ods.DataMatrix.Column.FloatArraysH\x00\x12>\n\x0e\x62oolean_arrays\x18\x12 \x01(\x0b\x32$.ods.DataMatrix.Column.BooleanArraysH\x00\x12\x38\n\x0b\x62yte_arrays\x18\x13 \x01(\x0b\x32!.ods.DataMatrix.Column.ByteArraysH\x00\x12<\n\rdouble_arrays\x18\x14 \x01(\x0b\x32#.ods.DataMatrix.Column.DoubleArraysH\x00\x12@\n\x0flonglong_arrays\x18\x15 \x01(\x0b\x32%.ods.DataMatrix.Column.LonglongArraysH\x00\x12>\n\x0e\x62ytestr_arrays\x18\x16 \x01(\x0b\x32$.ods.DataMatrix.Column.BytestrArraysH\x00\x12>\n\x0eunknown_arrays\x18\x17 \x01(\x0b\x32$.ods.DataMatrix.Column.UnknownArraysH\x00\x1a\xa3\x03\n\x0cUnknownArray\x12$\n\tdata_type\x18\x01 \x01(\x0e\x32\x11.ods.DataTypeEnum\x12\x0f\n\x07unit_id\x18\x02 \x01(\x03\x12(\n\x0cstring_array\x18\x03 \x01(\x0b\x32\x10.ods.StringArrayH\x00\x12$\n\nlong_array\x18\x04 \x01(\x0b\x32\x0e.ods.LongArrayH\x00\x12&\n\x0b\x66loat_array\x18\x05 \x01(\x0b\x32\x0f.ods.FloatArrayH\x00\x12*\n\rboolean_array\x18\x06 \x01(\x0b\x32\x11.ods.BooleanArrayH\x00\x12$\n\nbyte_array\x18\x07 \x01(\x0b\x32\x0e.ods.ByteArrayH\x00\x12(\n\x0c\x64ouble_array\x18\x08 \x01(\x0b\x32\x10.ods.DoubleArrayH\x00\x12,\n\x0elonglong_array\x18\t \x01(\x0b\x32\x12.ods.LonglongArrayH\x00\x12*\n\rbytestr_array\x18\n \x01(\x0b\x32\x11.ods.BytestrArrayH\x00\x42\x0e\n\x0cUnknownOneOf\x1a\x30\n\x0cStringArrays\x12 \n\x06values\x18\x01 \x03(\x0b\x32\x10.ods.StringArray\x1a,\n\nLongArrays\x12\x1e\n\x06values\x18\x01 \x03(\x0b\x32\x0e.ods.LongArray\x1a.\n\x0b\x46loatArrays\x12\x1f\n\x06values\x18\x01 \x03(\x0b\x32\x0f.ods.FloatArray\x1a\x32\n\rBooleanArrays\x12!\n\x06values\x18\x01 \x03(\x0b\x32\x11.ods.BooleanArray\x1a,\n\nByteArrays\x12\x1e\n\x06values\x18\x01 \x03(\x0b\x32\x0e.ods.ByteArray\x1a\x30\n\x0c\x44oubleArrays\x12 \n\x06values\x18\x01 \x03(\x0b\x32\x10.ods.DoubleArray\x1a\x34\n\x0eLonglongArrays\x12\"\n\x06values\x18\x01 \x03(\x0b\x32\x12.ods.LonglongArray\x1a\x32\n\rBytestrArrays\x12!\n\x06values\x18\x01 \x03(\x0b\x32\x11.ods.BytestrArray\x1a\x44\n\rUnknownArrays\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.ods.DataMatrix.Column.UnknownArrayB\r\n\x0bValuesOneOf\"L\n\x0eUpdateModeEnum\x12\r\n\tVU_APPEND\x10\x00\x12\r\n\tVU_UPDATE\x10\x01\x12\r\n\tVU_INSERT\x10\x02\x12\r\n\tVU_REMOVE\x10\x03\"I\n\x0c\x44\x61taMatrices\x12!\n\x08matrices\x18\x01 \x03(\x0b\x32\x0f.ods.DataMatrix\x12\x16\n\x0epartial_result\x18\x02 \x01(\x08\"\x8c\x0c\n\x05Model\x12\x32\n\x0c\x65numerations\x18\x01 \x03(\x0b\x32\x1c.ods.Model.EnumerationsEntry\x12*\n\x08\x65ntities\x18\x02 \x03(\x0b\x32\x18.ods.Model.EntitiesEntry\x1a{\n\x0b\x45numeration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.ods.Model.Enumeration.ItemsEntry\x1a,\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\xcf\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\x12$\n\tdata_type\x18\x03 \x01(\x0e\x32\x11.ods.DataTypeEnum\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x12\n\nobligatory\x18\x05 \x01(\x08\x12\x0e\n\x06unique\x18\x06 \x01(\x08\x12\x15\n\rautogenerated\x18\x07 \x01(\x08\x12\x0f\n\x07unit_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x65numeration\x18\t \x01(\t\x12\n\n\x02id\x18\n \x01(\x05\x1a\x94\x03\n\x08Relation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\x12\x14\n\x0cinverse_name\x18\x03 \x01(\t\x12\x19\n\x11inverse_base_name\x18\x04 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x05 \x01(\t\x12\x18\n\x10\x65ntity_base_name\x18\x06 \x01(\t\x12\x12\n\nentity_aid\x18\x07 \x01(\x03\x12\x19\n\x11virtual_reference\x18\x08 \x01(\x08\x12\x15\n\racl_reference\x18\t \x01(\x08\x12\x11\n\trange_min\x18\n \x01(\x05\x12\x11\n\trange_max\x18\x0b \x01(\x05\x12\x19\n\x11inverse_range_min\x18\x0c \x01(\x05\x12\x19\n\x11inverse_range_max\x18\r \x01(\x05\x12\x32\n\rrelation_type\x18\x0e \x01(\x0e\x32\x1b.ods.Model.RelationTypeEnum\x12\x31\n\x0crelationship\x18\x0f \x01(\x0e\x32\x1b.ods.Model.RelationshipEnum\x1a\xca\x02\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tbase_name\x18\x02 \x01(\t\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x16\n\x0esecurity_level\x18\x04 \x01(\x05\x12\x35\n\nattributes\x18\x05 \x03(\x0b\x32!.ods.Model.Entity.AttributesEntry\x12\x33\n\trelations\x18\x06 \x03(\x0b\x32 .ods.Model.Entity.RelationsEntry\x1aG\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.ods.Model.Attribute:\x02\x38\x01\x1a\x45\n\x0eRelationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.ods.Model.Relation:\x02\x38\x01\x1aK\n\x11\x45numerationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.ods.Model.Enumeration:\x02\x38\x01\x1a\x42\n\rEntitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.ods.Model.Entity:\x02\x38\x01\"H\n\x10RelationTypeEnum\x12\x13\n\x0fRT_FATHER_CHILD\x10\x00\x12\x0b\n\x07RT_INFO\x10\x01\x12\x12\n\x0eRT_INHERITANCE\x10\x02\"\x94\x01\n\x10RelationshipEnum\x12\r\n\tRS_FATHER\x10\x00\x12\x0c\n\x08RS_CHILD\x10\x01\x12\x0e\n\nRS_INFO_TO\x10\x02\x12\x10\n\x0cRS_INFO_FROM\x10\x03\x12\x0f\n\x0bRS_INFO_REL\x10\x04\x12\x10\n\x0cRS_SUPERTYPE\x10\x05\x12\x0e\n\nRS_SUBTYPE\x10\x06\x12\x0e\n\nRS_ALL_REL\x10\x07\"\x93\x0f\n\x0fSelectStatement\x12\x33\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\".ods.SelectStatement.AttributeItem\x12\x31\n\x05where\x18\x02 \x03(\x0b\x32\".ods.SelectStatement.ConditionItem\x12,\n\x05joins\x18\x03 \x03(\x0b\x32\x1d.ods.SelectStatement.JoinItem\x12\x32\n\x08order_by\x18\x04 \x03(\x0b\x32 .ods.SelectStatement.OrderByItem\x12\x32\n\x08group_by\x18\x05 \x03(\x0b\x32 .ods.SelectStatement.GroupByItem\x12\x11\n\trow_limit\x18\x06 \x01(\x03\x12\x11\n\trow_start\x18\x07 \x01(\x03\x12\x14\n\x0cvalues_limit\x18\x08 \x01(\x03\x12\x14\n\x0cvalues_start\x18\t \x01(\x03\x1a\xcc\x08\n\rConditionItem\x12H\n\x0b\x63onjunction\x18\x01 \x01(\x0e\x32\x31.ods.SelectStatement.ConditionItem.ConjuctionEnumH\x00\x12\x41\n\tcondition\x18\x02 \x01(\x0b\x32,.ods.SelectStatement.ConditionItem.ConditionH\x00\x1a\xd0\x06\n\tCondition\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0f\n\x07unit_id\x18\x03 \x01(\x03\x12K\n\x08operator\x18\x04 \x01(\x0e\x32\x39.ods.SelectStatement.ConditionItem.Condition.OperatorEnum\x12(\n\x0cstring_array\x18\x05 \x01(\x0b\x32\x10.ods.StringArrayH\x00\x12$\n\nlong_array\x18\x06 \x01(\x0b\x32\x0e.ods.LongArrayH\x00\x12&\n\x0b\x66loat_array\x18\x07 \x01(\x0b\x32\x0f.ods.FloatArrayH\x00\x12*\n\rboolean_array\x18\x08 \x01(\x0b\x32\x11.ods.BooleanArrayH\x00\x12$\n\nbyte_array\x18\t \x01(\x0b\x32\x0e.ods.ByteArrayH\x00\x12(\n\x0c\x64ouble_array\x18\n \x01(\x0b\x32\x10.ods.DoubleArrayH\x00\x12,\n\x0elonglong_array\x18\x0b \x01(\x0b\x32\x12.ods.LonglongArrayH\x00\x12\x30\n\x10nested_statement\x18\x0c \x01(\x0b\x32\x14.ods.SelectStatementH\x00\"\xe2\x02\n\x0cOperatorEnum\x12\t\n\x05OP_EQ\x10\x00\x12\n\n\x06OP_NEQ\x10\x01\x12\t\n\x05OP_LT\x10\x02\x12\t\n\x05OP_GT\x10\x03\x12\n\n\x06OP_LTE\x10\x04\x12\n\n\x06OP_GTE\x10\x05\x12\x0c\n\x08OP_INSET\x10\x06\x12\x0f\n\x0bOP_NOTINSET\x10\x07\x12\x0b\n\x07OP_LIKE\x10\x08\x12\x0c\n\x08OP_CI_EQ\x10\t\x12\r\n\tOP_CI_NEQ\x10\n\x12\x0c\n\x08OP_CI_LT\x10\x0b\x12\x0c\n\x08OP_CI_GT\x10\x0c\x12\r\n\tOP_CI_LTE\x10\r\x12\r\n\tOP_CI_GTE\x10\x0e\x12\x0f\n\x0bOP_CI_INSET\x10\x0f\x12\x12\n\x0eOP_CI_NOTINSET\x10\x10\x12\x0e\n\nOP_CI_LIKE\x10\x11\x12\x0e\n\nOP_IS_NULL\x10\x12\x12\x12\n\x0eOP_IS_NOT_NULL\x10\x13\x12\x0e\n\nOP_NOTLIKE\x10\x14\x12\x11\n\rOP_CI_NOTLIKE\x10\x15\x12\x0e\n\nOP_BETWEEN\x10\x16\x42\x0c\n\nValueOneOf\"N\n\x0e\x43onjuctionEnum\x12\n\n\x06\x43O_AND\x10\x00\x12\t\n\x05\x43O_OR\x10\x01\x12\n\n\x06\x43O_NOT\x10\x02\x12\x0b\n\x07\x43O_OPEN\x10\x03\x12\x0c\n\x08\x43O_CLOSE\x10\x04\x42\x0b\n\tItemOneOf\x1a\x9a\x01\n\x0bOrderByItem\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x39\n\x05order\x18\x03 \x01(\x0e\x32*.ods.SelectStatement.OrderByItem.OrderEnum\"0\n\tOrderEnum\x12\x10\n\x0cOD_ASCENDING\x10\x00\x12\x11\n\rOD_DESCENDING\x10\x01\x1a-\n\x0bGroupByItem\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x11\n\tattribute\x18\x02 \x01(\t\x1ag\n\rAttributeItem\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x11\n\tattribute\x18\x02 \x01(\t\x12%\n\taggregate\x18\x03 \x01(\x0e\x32\x12.ods.AggregateEnum\x12\x0f\n\x07unit_id\x18\x04 \x01(\x03\x1a\xab\x01\n\x08JoinItem\x12\x10\n\x08\x61id_from\x18\x01 \x01(\x03\x12\x0e\n\x06\x61id_to\x18\x02 \x01(\x03\x12\x10\n\x08relation\x18\x03 \x01(\t\x12=\n\tjoin_type\x18\x04 \x01(\x0e\x32*.ods.SelectStatement.JoinItem.JoinTypeEnum\",\n\x0cJoinTypeEnum\x12\x0e\n\nJT_DEFAULT\x10\x00\x12\x0c\n\x08JT_OUTER\x10\x01\"\xf1\x02\n\x18ValueMatrixRequestStruct\x12\x34\n\x04mode\x18\x01 \x01(\x0e\x32&.ods.ValueMatrixRequestStruct.ModeEnum\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03iid\x18\x03 \x01(\x03\x12\x12\n\nattributes\x18\x04 \x03(\t\x12\x39\n\x07\x63olumns\x18\x05 \x03(\x0b\x32(.ods.ValueMatrixRequestStruct.ColumnItem\x12\x14\n\x0cvalues_limit\x18\x06 \x01(\x03\x12\x14\n\x0cvalues_start\x18\x07 \x01(\x03\x12\x15\n\rexd_group_ids\x18\x08 \x03(\x03\x1a+\n\nColumnItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07unit_id\x18\x02 \x01(\x03\"F\n\x08ModeEnum\x12\x11\n\rMO_CALCULATED\x10\x00\x12\x0e\n\nMO_STORAGE\x10\x01\x12\x17\n\x13MO_EXD_VIRTUAL_DATA\x10\x02\"\xf2\x03\n\x10\x43ontextVariables\x12\x37\n\tvariables\x18\x01 \x03(\x0b\x32$.ods.ContextVariables.VariablesEntry\x1a\xc6\x02\n\x14\x43ontextVariableValue\x12(\n\x0cstring_array\x18\x01 \x01(\x0b\x32\x10.ods.StringArrayH\x00\x12$\n\nlong_array\x18\x02 \x01(\x0b\x32\x0e.ods.LongArrayH\x00\x12&\n\x0b\x66loat_array\x18\x03 \x01(\x0b\x32\x0f.ods.FloatArrayH\x00\x12*\n\rboolean_array\x18\x04 \x01(\x0b\x32\x11.ods.BooleanArrayH\x00\x12$\n\nbyte_array\x18\x05 \x01(\x0b\x32\x0e.ods.ByteArrayH\x00\x12(\n\x0c\x64ouble_array\x18\x06 \x01(\x0b\x32\x10.ods.DoubleArrayH\x00\x12,\n\x0elonglong_array\x18\x07 \x01(\x0b\x32\x12.ods.LonglongArrayH\x00\x42\x0c\n\nValueOneOf\x1a\\\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.ods.ContextVariables.ContextVariableValue:\x02\x38\x01\"\x18\n\x08\x41samPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"$\n\x08Instance\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03iid\x18\x02 \x01(\x03\"\xdd\r\n\tErrorInfo\x12.\n\x08\x65rr_code\x18\x01 \x01(\x0e\x32\x1c.ods.ErrorInfo.ErrorCodeEnum\x12\x12\n\nminor_code\x18\x02 \x01(\x05\x12\x0e\n\x06reason\x18\x03 \x01(\t\"\xfb\x0c\n\rErrorCodeEnum\x12\x14\n\x10\x41O_UNKNOWN_ERROR\x10\x00\x12\x14\n\x10\x41O_ACCESS_DENIED\x10\x01\x12\x14\n\x10\x41O_BAD_OPERATION\x10\x02\x12\x14\n\x10\x41O_BAD_PARAMETER\x10\x03\x12\x15\n\x11\x41O_CONNECT_FAILED\x10\x04\x12\x16\n\x12\x41O_CONNECT_REFUSED\x10\x05\x12\x16\n\x12\x41O_CONNECTION_LOST\x10\x06\x12\x1f\n\x1b\x41O_DUPLICATE_BASE_ATTRIBUTE\x10\x07\x12\x15\n\x11\x41O_DUPLICATE_NAME\x10\x08\x12\x16\n\x12\x41O_DUPLICATE_VALUE\x10\t\x12\x14\n\x10\x41O_HAS_INSTANCES\x10\n\x12\x15\n\x11\x41O_HAS_REFERENCES\x10\x0b\x12\x1d\n\x19\x41O_IMPLEMENTATION_PROBLEM\x10\x0c\x12\x19\n\x15\x41O_INCOMPATIBLE_UNITS\x10\r\x12\x18\n\x14\x41O_INVALID_ASAM_PATH\x10\x0e\x12\x1d\n\x19\x41O_INVALID_ATTRIBUTE_TYPE\x10\x0f\x12\x1b\n\x17\x41O_INVALID_BASE_ELEMENT\x10\x10\x12\x17\n\x13\x41O_INVALID_BASETYPE\x10\x11\x12\x1f\n\x1b\x41O_INVALID_BUILDUP_FUNCTION\x10\x12\x12\x15\n\x11\x41O_INVALID_COLUMN\x10\x13\x12\x14\n\x10\x41O_INVALID_COUNT\x10\x14\x12\x17\n\x13\x41O_INVALID_DATATYPE\x10\x15\x12\x16\n\x12\x41O_INVALID_ELEMENT\x10\x16\x12\x15\n\x11\x41O_INVALID_LENGTH\x10\x17\x12\x1c\n\x18\x41O_INVALID_ORDINALNUMBER\x10\x18\x12\x17\n\x13\x41O_INVALID_RELATION\x10\x19\x12\x1d\n\x19\x41O_INVALID_RELATION_RANGE\x10\x1a\x12\x1c\n\x18\x41O_INVALID_RELATION_TYPE\x10\x1b\x12\x1b\n\x17\x41O_INVALID_RELATIONSHIP\x10\x1c\x12\x17\n\x13\x41O_INVALID_SET_TYPE\x10\x1d\x12\x17\n\x13\x41O_INVALID_SMATLINK\x10\x1e\x12\x18\n\x14\x41O_INVALID_SUBMATRIX\x10\x1f\x12\x18\n\x14\x41O_IS_BASE_ATTRIBUTE\x10 \x12\x17\n\x13\x41O_IS_BASE_RELATION\x10!\x12\x1c\n\x18\x41O_IS_MEASUREMENT_MATRIX\x10\"\x12\x11\n\rAO_MATH_ERROR\x10#\x12\"\n\x1e\x41O_MISSING_APPLICATION_ELEMENT\x10$\x12\x18\n\x14\x41O_MISSING_ATTRIBUTE\x10%\x12\x17\n\x13\x41O_MISSING_RELATION\x10&\x12\x14\n\x10\x41O_MISSING_VALUE\x10\'\x12\x10\n\x0c\x41O_NO_MEMORY\x10(\x12\x19\n\x15\x41O_NO_PATH_TO_ELEMENT\x10)\x12\x10\n\x0c\x41O_NOT_FOUND\x10*\x12\x16\n\x12\x41O_NOT_IMPLEMENTED\x10+\x12\x11\n\rAO_NOT_UNIQUE\x10,\x12\x1e\n\x1a\x41O_OPEN_MODE_NOT_SUPPORTED\x10-\x12\x1c\n\x18\x41O_SESSION_LIMIT_REACHED\x10.\x12\x19\n\x15\x41O_SESSION_NOT_ACTIVE\x10/\x12!\n\x1d\x41O_TRANSACTION_ALREADY_ACTIVE\x10\x30\x12\x1d\n\x19\x41O_TRANSACTION_NOT_ACTIVE\x10\x31\x12\x18\n\x14\x41O_HAS_BASE_RELATION\x10\x32\x12\x19\n\x15\x41O_HAS_BASE_ATTRIBUTE\x10\x33\x12\x13\n\x0f\x41O_UNKNOWN_UNIT\x10\x34\x12\x18\n\x14\x41O_NO_SCALING_COLUMN\x10\x35\x12\x19\n\x15\x41O_QUERY_TYPE_INVALID\x10\x36\x12\x14\n\x10\x41O_QUERY_INVALID\x10\x37\x12\x1d\n\x19\x41O_QUERY_PROCESSING_ERROR\x10\x38\x12\x1d\n\x19\x41O_QUERY_TIMEOUT_EXCEEDED\x10\x39\x12\x17\n\x13\x41O_QUERY_INCOMPLETE\x10:\x12\x1f\n\x1b\x41O_QUERY_INVALID_RESULTTYPE\x10;\x12$\n AO_INVALID_VALUEMATRIX_STRUCTURE\x10<\x12\x12\n\x0e\x41O_FILE_LOCKED\x10=\x12\x15\n\x11\x41O_SYSTEM_PROBLEM\x10>\")\n\x16\x43ontextVariablesFilter\x12\x0f\n\x07pattern\x18\x01 \x01(\t\"L\n\x0e\x46ileIdentifier\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03iid\x18\x02 \x01(\x03\x12\x11\n\tattribute\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x03\"\x8b\x01\n\x0b\x46ileControl\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03iid\x18\x02 \x01(\x03\x12\x0b\n\x03url\x18\x03 \x01(\t\x12+\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32\x1b.ods.FileControl.ActionEnum\"(\n\nActionEnum\x12\x0b\n\x07\x41\x43_TAKE\x10\x00\x12\r\n\tAC_REMOVE\x10\x01\"\x95\t\n\tBaseModel\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x0c\x65numerations\x18\x02 \x03(\x0b\x32 .ods.BaseModel.EnumerationsEntry\x12.\n\x08\x65ntities\x18\x03 \x03(\x0b\x32\x1c.ods.BaseModel.EntitiesEntry\x1a\x92\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\tdata_type\x18\x02 \x01(\x0e\x32\x11.ods.DataTypeEnum\x12\x11\n\tmandatory\x18\x03 \x01(\x08\x12\x12\n\nobligatory\x18\x04 \x01(\x08\x12\x15\n\rautogenerated\x18\x05 \x01(\x08\x12\x13\n\x0b\x65numeration\x18\x06 \x01(\t\x1a\x9a\x02\n\x08Relation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cinverse_name\x18\x02 \x01(\t\x12\x14\n\x0c\x65ntity_names\x18\x03 \x03(\t\x12\x11\n\trange_min\x18\x04 \x01(\x05\x12\x11\n\trange_max\x18\x05 \x01(\x05\x12\x31\n\x0crelationship\x18\x06 \x01(\x0e\x32\x1b.ods.Model.RelationshipEnum\x12\x19\n\x11inverse_range_min\x18\x07 \x01(\x05\x12\x19\n\x11inverse_range_max\x18\x08 \x01(\x05\x12\x32\n\rrelation_type\x18\t \x01(\x0e\x32\x1b.ods.Model.RelationTypeEnum\x12\x11\n\tmandatory\x18\n \x01(\x08\x1a\xe2\x02\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x62id\x18\x02 \x01(\x03\x12\x31\n\nderivation\x18\x03 \x01(\x0e\x32\x1d.ods.BaseModel.DerivationEnum\x12\x39\n\nattributes\x18\x04 \x03(\x0b\x32%.ods.BaseModel.Entity.AttributesEntry\x12\x37\n\trelations\x18\x05 \x03(\x0b\x32$.ods.BaseModel.Entity.RelationsEntry\x1aK\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.ods.BaseModel.Attribute:\x02\x38\x01\x1aI\n\x0eRelationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.ods.BaseModel.Relation:\x02\x38\x01\x1aK\n\x11\x45numerationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.ods.Model.Enumeration:\x02\x38\x01\x1a\x46\n\rEntitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.ods.BaseModel.Entity:\x02\x38\x01\"c\n\x0e\x44\x65rivationEnum\x12\x13\n\x0f\x44V_UNRESTRICTED\x10\x00\x12\r\n\tDV_SINGLE\x10\x01\x12\x17\n\x13\x44V_TREE_AT_INSTANCE\x10\x02\x12\x14\n\x10\x44V_TREE_AT_MODEL\x10\x03\"^\n\x16NtoMRelationIdentifier\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03iid\x18\x02 \x01(\x03\x12\x15\n\rrelation_name\x18\x03 \x01(\t\x12\x13\n\x0brelated_aid\x18\x04 \x01(\x03\"]\n\x14NtoMRelatedInstances\x12/\n\nidentifier\x18\x01 \x01(\x0b\x32\x1b.ods.NtoMRelationIdentifier\x12\x14\n\x0crelated_iids\x18\x02 \x03(\x03\"\xc8\x01\n\x19NtoMWriteRelatedInstances\x12\x41\n\x0b\x63hange_mode\x18\x01 \x01(\x0e\x32,.ods.NtoMWriteRelatedInstances.WriteTypeEnum\x12\x30\n\rrelation_info\x18\x02 \x01(\x0b\x32\x19.ods.NtoMRelatedInstances\"6\n\rWriteTypeEnum\x12\n\n\x06WT_ADD\x10\x00\x12\r\n\tWT_REMOVE\x10\x01\x12\n\n\x06WT_SET\x10\x02\"\xa8\x01\n\x0b\x43opyRequest\x12+\n\x04mode\x18\x01 \x01(\x0e\x32\x1d.ods.CopyRequest.CopyModeEnum\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03iid\x18\x03 \x01(\x03\x12\x10\n\x08new_name\x18\x04 \x01(\t\x12\x13\n\x0bnew_version\x18\x05 \x01(\t\"+\n\x0c\x43opyModeEnum\x12\x0e\n\nCM_SHALLOW\x10\x00\x12\x0b\n\x07\x43M_DEEP\x10\x01\"M\n\x0ePasswordUpdate\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0cold_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t*\xdf\x03\n\x0c\x44\x61taTypeEnum\x12\x0e\n\nDT_UNKNOWN\x10\x00\x12\r\n\tDT_STRING\x10\x01\x12\x0c\n\x08\x44T_SHORT\x10\x02\x12\x0c\n\x08\x44T_FLOAT\x10\x03\x12\x0e\n\nDT_BOOLEAN\x10\x04\x12\x0b\n\x07\x44T_BYTE\x10\x05\x12\x0b\n\x07\x44T_LONG\x10\x06\x12\r\n\tDT_DOUBLE\x10\x07\x12\x0f\n\x0b\x44T_LONGLONG\x10\x08\x12\x0b\n\x07\x44T_DATE\x10\n\x12\x0e\n\nDT_BYTESTR\x10\x0b\x12\x0b\n\x07\x44T_BLOB\x10\x0c\x12\x0e\n\nDT_COMPLEX\x10\r\x12\x0f\n\x0b\x44T_DCOMPLEX\x10\x0e\x12\r\n\tDS_STRING\x10\x0f\x12\x0c\n\x08\x44S_SHORT\x10\x10\x12\x0c\n\x08\x44S_FLOAT\x10\x11\x12\x0e\n\nDS_BOOLEAN\x10\x12\x12\x0b\n\x07\x44S_BYTE\x10\x13\x12\x0b\n\x07\x44S_LONG\x10\x14\x12\r\n\tDS_DOUBLE\x10\x15\x12\x0f\n\x0b\x44S_LONGLONG\x10\x16\x12\x0e\n\nDS_COMPLEX\x10\x17\x12\x0f\n\x0b\x44S_DCOMPLEX\x10\x18\x12\x0b\n\x07\x44S_DATE\x10\x1a\x12\x0e\n\nDS_BYTESTR\x10\x1b\x12\x18\n\x14\x44T_EXTERNALREFERENCE\x10\x1c\x12\x18\n\x14\x44S_EXTERNALREFERENCE\x10\x1d\x12\x0b\n\x07\x44T_ENUM\x10\x1e\x12\x0b\n\x07\x44S_ENUM\x10\x1f*\xb9\x01\n\rAggregateEnum\x12\x0b\n\x07\x41G_NONE\x10\x00\x12\x0c\n\x08\x41G_COUNT\x10\x01\x12\r\n\tAG_DCOUNT\x10\x02\x12\n\n\x06\x41G_MIN\x10\x03\x12\n\n\x06\x41G_MAX\x10\x04\x12\n\n\x06\x41G_AVG\x10\x05\x12\r\n\tAG_STDDEV\x10\x06\x12\n\n\x06\x41G_SUM\x10\x07\x12\x0f\n\x0b\x41G_DISTINCT\x10\x08\x12\x13\n\x0f\x41G_VALUES_POINT\x10\t\x12\x19\n\x15\x41G_INSTANCE_ATTRIBUTE\x10\nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'odsbox.proto.ods_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LONGARRAY'].fields_by_name['values']._loaded_options = None
  _globals['_LONGARRAY'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_FLOATARRAY'].fields_by_name['values']._loaded_options = None
  _globals['_FLOATARRAY'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_BOOLEANARRAY'].fields_by_name['values']._loaded_options = None
  _globals['_BOOLEANARRAY'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_DOUBLEARRAY'].fields_by_name['values']._loaded_options = None
  _globals['_DOUBLEARRAY'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_LONGLONGARRAY'].fields_by_name['values']._loaded_options = None
  _globals['_LONGLONGARRAY'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_DATAMATRIX_COLUMN'].fields_by_name['is_null']._loaded_options = None
  _globals['_DATAMATRIX_COLUMN'].fields_by_name['is_null']._serialized_options = b'\020\001'
  _globals['_MODEL_ENUMERATION_ITEMSENTRY']._loaded_options = None
  _globals['_MODEL_ENUMERATION_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_MODEL_ENTITY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_MODEL_ENTITY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_MODEL_ENTITY_RELATIONSENTRY']._loaded_options = None
  _globals['_MODEL_ENTITY_RELATIONSENTRY']._serialized_options = b'8\001'
  _globals['_MODEL_ENUMERATIONSENTRY']._loaded_options = None
  _globals['_MODEL_ENUMERATIONSENTRY']._serialized_options = b'8\001'
  _globals['_MODEL_ENTITIESENTRY']._loaded_options = None
  _globals['_MODEL_ENTITIESENTRY']._serialized_options = b'8\001'
  _globals['_CONTEXTVARIABLES_VARIABLESENTRY']._loaded_options = None
  _globals['_CONTEXTVARIABLES_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_BASEMODEL_ENTITY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_BASEMODEL_ENTITY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_BASEMODEL_ENTITY_RELATIONSENTRY']._loaded_options = None
  _globals['_BASEMODEL_ENTITY_RELATIONSENTRY']._serialized_options = b'8\001'
  _globals['_BASEMODEL_ENUMERATIONSENTRY']._loaded_options = None
  _globals['_BASEMODEL_ENUMERATIONSENTRY']._serialized_options = b'8\001'
  _globals['_BASEMODEL_ENTITIESENTRY']._loaded_options = None
  _globals['_BASEMODEL_ENTITIESENTRY']._serialized_options = b'8\001'
  _globals['_DATATYPEENUM']._serialized_start=10914
  _globals['_DATATYPEENUM']._serialized_end=11393
  _globals['_AGGREGATEENUM']._serialized_start=11396
  _globals['_AGGREGATEENUM']._serialized_end=11581
  _globals['_STRINGARRAY']._serialized_start=31
  _globals['_STRINGARRAY']._serialized_end=60
  _globals['_LONGARRAY']._serialized_start=62
  _globals['_LONGARRAY']._serialized_end=93
  _globals['_FLOATARRAY']._serialized_start=95
  _globals['_FLOATARRAY']._serialized_end=127
  _globals['_BOOLEANARRAY']._serialized_start=129
  _globals['_BOOLEANARRAY']._serialized_end=163
  _globals['_BYTEARRAY']._serialized_start=165
  _globals['_BYTEARRAY']._serialized_end=192
  _globals['_DOUBLEARRAY']._serialized_start=194
  _globals['_DOUBLEARRAY']._serialized_end=227
  _globals['_LONGLONGARRAY']._serialized_start=229
  _globals['_LONGLONGARRAY']._serialized_end=264
  _globals['_BYTESTRARRAY']._serialized_start=266
  _globals['_BYTESTRARRAY']._serialized_end=296
  _globals['_DATAMATRIX']._serialized_start=299
  _globals['_DATAMATRIX']._serialized_end=2563
  _globals['_DATAMATRIX_COLUMN']._serialized_start=532
  _globals['_DATAMATRIX_COLUMN']._serialized_end=2485
  _globals['_DATAMATRIX_COLUMN_UNKNOWNARRAY']._serialized_start=1583
  _globals['_DATAMATRIX_COLUMN_UNKNOWNARRAY']._serialized_end=2002
  _globals['_DATAMATRIX_COLUMN_STRINGARRAYS']._serialized_start=2004
  _globals['_DATAMATRIX_COLUMN_STRINGARRAYS']._serialized_end=2052
  _globals['_DATAMATRIX_COLUMN_LONGARRAYS']._serialized_start=2054
  _globals['_DATAMATRIX_COLUMN_LONGARRAYS']._serialized_end=2098
  _globals['_DATAMATRIX_COLUMN_FLOATARRAYS']._serialized_start=2100
  _globals['_DATAMATRIX_COLUMN_FLOATARRAYS']._serialized_end=2146
  _globals['_DATAMATRIX_COLUMN_BOOLEANARRAYS']._serialized_start=2148
  _globals['_DATAMATRIX_COLUMN_BOOLEANARRAYS']._serialized_end=2198
  _globals['_DATAMATRIX_COLUMN_BYTEARRAYS']._serialized_start=2200
  _globals['_DATAMATRIX_COLUMN_BYTEARRAYS']._serialized_end=2244
  _globals['_DATAMATRIX_COLUMN_DOUBLEARRAYS']._serialized_start=2246
  _globals['_DATAMATRIX_COLUMN_DOUBLEARRAYS']._serialized_end=2294
  _globals['_DATAMATRIX_COLUMN_LONGLONGARRAYS']._serialized_start=2296
  _globals['_DATAMATRIX_COLUMN_LONGLONGARRAYS']._serialized_end=2348
  _globals['_DATAMATRIX_COLUMN_BYTESTRARRAYS']._serialized_start=2350
  _globals['_DATAMATRIX_COLUMN_BYTESTRARRAYS']._serialized_end=2400
  _globals['_DATAMATRIX_COLUMN_UNKNOWNARRAYS']._serialized_start=2402
  _globals['_DATAMATRIX_COLUMN_UNKNOWNARRAYS']._serialized_end=2470
  _globals['_DATAMATRIX_UPDATEMODEENUM']._serialized_start=2487
  _globals['_DATAMATRIX_UPDATEMODEENUM']._serialized_end=2563
  _globals['_DATAMATRICES']._serialized_start=2565
  _globals['_DATAMATRICES']._serialized_end=2638
  _globals['_MODEL']._serialized_start=2641
  _globals['_MODEL']._serialized_end=4189
  _globals['_MODEL_ENUMERATION']._serialized_start=2746
  _globals['_MODEL_ENUMERATION']._serialized_end=2869
  _globals['_MODEL_ENUMERATION_ITEMSENTRY']._serialized_start=2825
  _globals['_MODEL_ENUMERATION_ITEMSENTRY']._serialized_end=2869
  _globals['_MODEL_ATTRIBUTE']._serialized_start=2872
  _globals['_MODEL_ATTRIBUTE']._serialized_end=3079
  _globals['_MODEL_RELATION']._serialized_start=3082
  _globals['_MODEL_RELATION']._serialized_end=3486
  _globals['_MODEL_ENTITY']._serialized_start=3489
  _globals['_MODEL_ENTITY']._serialized_end=3819
  _globals['_MODEL_ENTITY_ATTRIBUTESENTRY']._serialized_start=3677
  _globals['_MODEL_ENTITY_ATTRIBUTESENTRY']._serialized_end=3748
  _globals['_MODEL_ENTITY_RELATIONSENTRY']._serialized_start=3750
  _globals['_MODEL_ENTITY_RELATIONSENTRY']._serialized_end=3819
  _globals['_MODEL_ENUMERATIONSENTRY']._serialized_start=3821
  _globals['_MODEL_ENUMERATIONSENTRY']._serialized_end=3896
  _globals['_MODEL_ENTITIESENTRY']._serialized_start=3898
  _globals['_MODEL_ENTITIESENTRY']._serialized_end=3964
  _globals['_MODEL_RELATIONTYPEENUM']._serialized_start=3966
  _globals['_MODEL_RELATIONTYPEENUM']._serialized_end=4038
  _globals['_MODEL_RELATIONSHIPENUM']._serialized_start=4041
  _globals['_MODEL_RELATIONSHIPENUM']._serialized_end=4189
  _globals['_SELECTSTATEMENT']._serialized_start=4192
  _globals['_SELECTSTATEMENT']._serialized_end=6131
  _globals['_SELECTSTATEMENT_CONDITIONITEM']._serialized_start=4548
  _globals['_SELECTSTATEMENT_CONDITIONITEM']._serialized_end=5648
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONDITION']._serialized_start=4707
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONDITION']._serialized_end=5555
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONDITION_OPERATORENUM']._serialized_start=5187
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONDITION_OPERATORENUM']._serialized_end=5541
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONJUCTIONENUM']._serialized_start=5557
  _globals['_SELECTSTATEMENT_CONDITIONITEM_CONJUCTIONENUM']._serialized_end=5635
  _globals['_SELECTSTATEMENT_ORDERBYITEM']._serialized_start=5651
  _globals['_SELECTSTATEMENT_ORDERBYITEM']._serialized_end=5805
  _globals['_SELECTSTATEMENT_ORDERBYITEM_ORDERENUM']._serialized_start=5757
  _globals['_SELECTSTATEMENT_ORDERBYITEM_ORDERENUM']._serialized_end=5805
  _globals['_SELECTSTATEMENT_GROUPBYITEM']._serialized_start=5807
  _globals['_SELECTSTATEMENT_GROUPBYITEM']._serialized_end=5852
  _globals['_SELECTSTATEMENT_ATTRIBUTEITEM']._serialized_start=5854
  _globals['_SELECTSTATEMENT_ATTRIBUTEITEM']._serialized_end=5957
  _globals['_SELECTSTATEMENT_JOINITEM']._serialized_start=5960
  _globals['_SELECTSTATEMENT_JOINITEM']._serialized_end=6131
  _globals['_SELECTSTATEMENT_JOINITEM_JOINTYPEENUM']._serialized_start=6087
  _globals['_SELECTSTATEMENT_JOINITEM_JOINTYPEENUM']._serialized_end=6131
  _globals['_VALUEMATRIXREQUESTSTRUCT']._serialized_start=6134
  _globals['_VALUEMATRIXREQUESTSTRUCT']._serialized_end=6503
  _globals['_VALUEMATRIXREQUESTSTRUCT_COLUMNITEM']._serialized_start=6388
  _globals['_VALUEMATRIXREQUESTSTRUCT_COLUMNITEM']._serialized_end=6431
  _globals['_VALUEMATRIXREQUESTSTRUCT_MODEENUM']._serialized_start=6433
  _globals['_VALUEMATRIXREQUESTSTRUCT_MODEENUM']._serialized_end=6503
  _globals['_CONTEXTVARIABLES']._serialized_start=6506
  _globals['_CONTEXTVARIABLES']._serialized_end=7004
  _globals['_CONTEXTVARIABLES_CONTEXTVARIABLEVALUE']._serialized_start=6584
  _globals['_CONTEXTVARIABLES_CONTEXTVARIABLEVALUE']._serialized_end=6910
  _globals['_CONTEXTVARIABLES_VARIABLESENTRY']._serialized_start=6912
  _globals['_CONTEXTVARIABLES_VARIABLESENTRY']._serialized_end=7004
  _globals['_ASAMPATH']._serialized_start=7006
  _globals['_ASAMPATH']._serialized_end=7030
  _globals['_INSTANCE']._serialized_start=7032
  _globals['_INSTANCE']._serialized_end=7068
  _globals['_ERRORINFO']._serialized_start=7071
  _globals['_ERRORINFO']._serialized_end=8828
  _globals['_ERRORINFO_ERRORCODEENUM']._serialized_start=7169
  _globals['_ERRORINFO_ERRORCODEENUM']._serialized_end=8828
  _globals['_CONTEXTVARIABLESFILTER']._serialized_start=8830
  _globals['_CONTEXTVARIABLESFILTER']._serialized_end=8871
  _globals['_FILEIDENTIFIER']._serialized_start=8873
  _globals['_FILEIDENTIFIER']._serialized_end=8949
  _globals['_FILECONTROL']._serialized_start=8952
  _globals['_FILECONTROL']._serialized_end=9091
  _globals['_FILECONTROL_ACTIONENUM']._serialized_start=9051
  _globals['_FILECONTROL_ACTIONENUM']._serialized_end=9091
  _globals['_BASEMODEL']._serialized_start=9094
  _globals['_BASEMODEL']._serialized_end=10267
  _globals['_BASEMODEL_ATTRIBUTE']._serialized_start=9229
  _globals['_BASEMODEL_ATTRIBUTE']._serialized_end=9375
  _globals['_BASEMODEL_RELATION']._serialized_start=9378
  _globals['_BASEMODEL_RELATION']._serialized_end=9660
  _globals['_BASEMODEL_ENTITY']._serialized_start=9663
  _globals['_BASEMODEL_ENTITY']._serialized_end=10017
  _globals['_BASEMODEL_ENTITY_ATTRIBUTESENTRY']._serialized_start=9867
  _globals['_BASEMODEL_ENTITY_ATTRIBUTESENTRY']._serialized_end=9942
  _globals['_BASEMODEL_ENTITY_RELATIONSENTRY']._serialized_start=9944
  _globals['_BASEMODEL_ENTITY_RELATIONSENTRY']._serialized_end=10017
  _globals['_BASEMODEL_ENUMERATIONSENTRY']._serialized_start=3821
  _globals['_BASEMODEL_ENUMERATIONSENTRY']._serialized_end=3896
  _globals['_BASEMODEL_ENTITIESENTRY']._serialized_start=10096
  _globals['_BASEMODEL_ENTITIESENTRY']._serialized_end=10166
  _globals['_BASEMODEL_DERIVATIONENUM']._serialized_start=10168
  _globals['_BASEMODEL_DERIVATIONENUM']._serialized_end=10267
  _globals['_NTOMRELATIONIDENTIFIER']._serialized_start=10269
  _globals['_NTOMRELATIONIDENTIFIER']._serialized_end=10363
  _globals['_NTOMRELATEDINSTANCES']._serialized_start=10365
  _globals['_NTOMRELATEDINSTANCES']._serialized_end=10458
  _globals['_NTOMWRITERELATEDINSTANCES']._serialized_start=10461
  _globals['_NTOMWRITERELATEDINSTANCES']._serialized_end=10661
  _globals['_NTOMWRITERELATEDINSTANCES_WRITETYPEENUM']._serialized_start=10607
  _globals['_NTOMWRITERELATEDINSTANCES_WRITETYPEENUM']._serialized_end=10661
  _globals['_COPYREQUEST']._serialized_start=10664
  _globals['_COPYREQUEST']._serialized_end=10832
  _globals['_COPYREQUEST_COPYMODEENUM']._serialized_start=10789
  _globals['_COPYREQUEST_COPYMODEENUM']._serialized_end=10832
  _globals['_PASSWORDUPDATE']._serialized_start=10834
  _globals['_PASSWORDUPDATE']._serialized_end=10911
# @@protoc_insertion_point(module_scope)
